Description Usage Arguments Value
View source: R/trends_rolling_average.R
Calculate rolling averages
1 | rolling_average(x, window_days = 7)
|
x |
The time series for which to calculate the rolling average (for column "val"). |
window_days |
The length of the window in days for the rolling average (default = 7). |
The time series with the rolling average added in new column "rolling_avg".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.